# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UrbanFloodingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_result_urban_flooding_flooding_area_by_page_get(self, scenario_id, **kwargs):  # noqa: E501
        """分页查询内涝积水区域信息 Get flooding area  # noqa: E501

        分页查询内涝方案的结果中，所有最大积水深度大于指定水深阈值的网格信息Get elements in the flooding area whose maximum water depth are above the specified threshold of a flood scenario.  order by elements id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_flooding_area_by_page_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param int page_index: 分页的序号，从1开始 page index, start from 1
        :param int page_size: 分页的大小 page size
        :param float threshold: 内涝积水深度阈值 flood water depth threshold
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StringPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_urban_flooding_flooding_area_by_page_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_urban_flooding_flooding_area_by_page_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """分页查询内涝积水区域信息 Get flooding area  # noqa: E501

        分页查询内涝方案的结果中，所有最大积水深度大于指定水深阈值的网格信息Get elements in the flooding area whose maximum water depth are above the specified threshold of a flood scenario.  order by elements id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_flooding_area_by_page_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param int page_index: 分页的序号，从1开始 page index, start from 1
        :param int page_size: 分页的大小 page size
        :param float threshold: 内涝积水深度阈值 flood water depth threshold
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StringPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'page_index',
            'page_size',
            'threshold'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_urban_flooding_flooding_area_by_page_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_urban_flooding_flooding_area_by_page_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_index' in local_var_params and local_var_params['page_index'] is not None:  # noqa: E501
            query_params.append(('PageIndex', local_var_params['page_index']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('PageSize', local_var_params['page_size']))  # noqa: E501
        if 'threshold' in local_var_params and local_var_params['threshold'] is not None:  # noqa: E501
            query_params.append(('Threshold', local_var_params['threshold']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/urban-flooding/flooding-area/by-page', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_urban_flooding_flooding_area_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取内涝积水区域信息 Get flooding area  # noqa: E501

        获取内涝方案的结果中，所有最大积水深度大于指定水深阈值的网格信息 Get all the elements in the flooding area whose maximum water depth are above the specified threshold of a flood scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_flooding_area_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param float threshold: 内涝积水深度阈值 flood water depth threshold
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_urban_flooding_flooding_area_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_urban_flooding_flooding_area_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取内涝积水区域信息 Get flooding area  # noqa: E501

        获取内涝方案的结果中，所有最大积水深度大于指定水深阈值的网格信息 Get all the elements in the flooding area whose maximum water depth are above the specified threshold of a flood scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_flooding_area_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param float threshold: 内涝积水深度阈值 flood water depth threshold
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[str], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'threshold'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_urban_flooding_flooding_area_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_urban_flooding_flooding_area_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'threshold' in local_var_params and local_var_params['threshold'] is not None:  # noqa: E501
            query_params.append(('Threshold', local_var_params['threshold']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/urban-flooding/flooding-area', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_urban_flooding_flooding_risk_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取洪水风险信息 Get Flood risk  result  # noqa: E501

        获取内涝方案的不同等级洪水风险区域信息，包括风险区域的几何形状和面积等 Get flood risk area information, including geometry and area of a flood scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_flooding_risk_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[FloodingRiskInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_urban_flooding_flooding_risk_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_urban_flooding_flooding_risk_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取洪水风险信息 Get Flood risk  result  # noqa: E501

        获取内涝方案的不同等级洪水风险区域信息，包括风险区域的几何形状和面积等 Get flood risk area information, including geometry and area of a flood scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_flooding_risk_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[FloodingRiskInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_urban_flooding_flooding_risk_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_urban_flooding_flooding_risk_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/urban-flooding/flooding-risk', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[FloodingRiskInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_urban_flooding_sensitive_points_statistics_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取易涝点统计信息 Get flood sensitive points statistics  # noqa: E501

        获取内涝方案的易涝点统计结果，每个易涝点返回一组平均水深、最小水深、最大水深的时间序列 Get average water depth,min water depth and max water depth of all the flood sensitive points of a flood scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_sensitive_points_statistics_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[SensitivePointsStatistic]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_urban_flooding_sensitive_points_statistics_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_urban_flooding_sensitive_points_statistics_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取易涝点统计信息 Get flood sensitive points statistics  # noqa: E501

        获取内涝方案的易涝点统计结果，每个易涝点返回一组平均水深、最小水深、最大水深的时间序列 Get average water depth,min water depth and max water depth of all the flood sensitive points of a flood scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_urban_flooding_sensitive_points_statistics_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[SensitivePointsStatistic], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_urban_flooding_sensitive_points_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_urban_flooding_sensitive_points_statistics_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/urban-flooding/sensitive-points-statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SensitivePointsStatistic]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class AddModelPrecisionConfigInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'region_name': 'str',
        'rec_probability': 'str',
        'region_s_value': 'float',
        'region_e_value': 'float',
        'sort': 'int',
        'code': 'str'
    }

    attribute_map = {
        'region_name': 'regionName',
        'rec_probability': 'recProbability',
        'region_s_value': 'regionSValue',
        'region_e_value': 'regionEValue',
        'sort': 'sort',
        'code': 'code'
    }

    def __init__(self, region_name=None, rec_probability=None, region_s_value=None, region_e_value=None, sort=None, code=None, local_vars_configuration=None):  # noqa: E501
        """AddModelPrecisionConfigInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._region_name = None
        self._rec_probability = None
        self._region_s_value = None
        self._region_e_value = None
        self._sort = None
        self._code = None
        self.discriminator = None

        self.region_name = region_name
        self.rec_probability = rec_probability
        if region_s_value is not None:
            self.region_s_value = region_s_value
        if region_e_value is not None:
            self.region_e_value = region_e_value
        if sort is not None:
            self.sort = sort
        self.code = code

    @property
    def region_name(self):
        """Gets the region_name of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间名称,如:80-100(优秀) precision region name  # noqa: E501

        :return: The region_name of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._region_name

    @region_name.setter
    def region_name(self, region_name):
        """Sets the region_name of this AddModelPrecisionConfigInput.

        百分比区间名称,如:80-100(优秀) precision region name  # noqa: E501

        :param region_name: The region_name of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: str
        """

        self._region_name = region_name

    @property
    def rec_probability(self):
        """Gets the rec_probability of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间推荐:如:>70 precison region recommended proportion  # noqa: E501

        :return: The rec_probability of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._rec_probability

    @rec_probability.setter
    def rec_probability(self, rec_probability):
        """Sets the rec_probability of this AddModelPrecisionConfigInput.

        百分比区间推荐:如:>70 precison region recommended proportion  # noqa: E501

        :param rec_probability: The rec_probability of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: str
        """

        self._rec_probability = rec_probability

    @property
    def region_s_value(self):
        """Gets the region_s_value of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间开始,如:80 precision region start value  # noqa: E501

        :return: The region_s_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: float
        """
        return self._region_s_value

    @region_s_value.setter
    def region_s_value(self, region_s_value):
        """Sets the region_s_value of this AddModelPrecisionConfigInput.

        百分比区间开始,如:80 precision region start value  # noqa: E501

        :param region_s_value: The region_s_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: float
        """

        self._region_s_value = region_s_value

    @property
    def region_e_value(self):
        """Gets the region_e_value of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间截止,如:100 precision region end value  # noqa: E501

        :return: The region_e_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: float
        """
        return self._region_e_value

    @region_e_value.setter
    def region_e_value(self, region_e_value):
        """Sets the region_e_value of this AddModelPrecisionConfigInput.

        百分比区间截止,如:100 precision region end value  # noqa: E501

        :param region_e_value: The region_e_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: float
        """

        self._region_e_value = region_e_value

    @property
    def sort(self):
        """Gets the sort of this AddModelPrecisionConfigInput.  # noqa: E501

        排序号,越小越靠前 precision region index  # noqa: E501

        :return: The sort of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this AddModelPrecisionConfigInput.

        排序号,越小越靠前 precision region index  # noqa: E501

        :param sort: The sort of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: int
        """

        self._sort = sort

    @property
    def code(self):
        """Gets the code of this AddModelPrecisionConfigInput.  # noqa: E501

        指标 system point code  # noqa: E501

        :return: The code of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this AddModelPrecisionConfigInput.

        指标 system point code  # noqa: E501

        :param code: The code of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: str
        """

        self._code = code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddModelPrecisionConfigInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddModelPrecisionConfigInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_configuration_service.configuration import Configuration


class LibraryInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'tenant_id': 'str',
        'scenario_group': 'str',
        'name': 'str',
        'type': 'LibraryTypeEnum',
        'business_type': 'BusinessTypeEnum',
        'readonly': 'int',
        'bind_template': 'int',
        'bind_library': 'LibraryTypeEnum',
        'bind_business': 'BusinessTypeEnum',
        'description': 'str',
        'enable_multi_template': 'int'
    }

    attribute_map = {
        'id': 'id',
        'tenant_id': 'tenantId',
        'scenario_group': 'scenarioGroup',
        'name': 'name',
        'type': 'type',
        'business_type': 'businessType',
        'readonly': 'readonly',
        'bind_template': 'bindTemplate',
        'bind_library': 'bindLibrary',
        'bind_business': 'bindBusiness',
        'description': 'description',
        'enable_multi_template': 'enableMultiTemplate'
    }

    def __init__(self, id=None, tenant_id=None, scenario_group=None, name=None, type=None, business_type=None, readonly=None, bind_template=None, bind_library=None, bind_business=None, description=None, enable_multi_template=None, local_vars_configuration=None):  # noqa: E501
        """LibraryInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._tenant_id = None
        self._scenario_group = None
        self._name = None
        self._type = None
        self._business_type = None
        self._readonly = None
        self._bind_template = None
        self._bind_library = None
        self._bind_business = None
        self._description = None
        self._enable_multi_template = None
        self.discriminator = None

        self.id = id
        self.tenant_id = tenant_id
        self.scenario_group = scenario_group
        self.name = name
        if type is not None:
            self.type = type
        if business_type is not None:
            self.business_type = business_type
        if readonly is not None:
            self.readonly = readonly
        if bind_template is not None:
            self.bind_template = bind_template
        if bind_library is not None:
            self.bind_library = bind_library
        if bind_business is not None:
            self.bind_business = bind_business
        self.description = description
        self.enable_multi_template = enable_multi_template

    @property
    def id(self):
        """Gets the id of this LibraryInfo.  # noqa: E501

        库的ID library Id  # noqa: E501

        :return: The id of this LibraryInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LibraryInfo.

        库的ID library Id  # noqa: E501

        :param id: The id of this LibraryInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this LibraryInfo.  # noqa: E501

        租户ID tenant Id  # noqa: E501

        :return: The tenant_id of this LibraryInfo.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this LibraryInfo.

        租户ID tenant Id  # noqa: E501

        :param tenant_id: The tenant_id of this LibraryInfo.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def scenario_group(self):
        """Gets the scenario_group of this LibraryInfo.  # noqa: E501

        对应的方案组ID scenario group Id  # noqa: E501

        :return: The scenario_group of this LibraryInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_group

    @scenario_group.setter
    def scenario_group(self, scenario_group):
        """Sets the scenario_group of this LibraryInfo.

        对应的方案组ID scenario group Id  # noqa: E501

        :param scenario_group: The scenario_group of this LibraryInfo.  # noqa: E501
        :type: str
        """

        self._scenario_group = scenario_group

    @property
    def name(self):
        """Gets the name of this LibraryInfo.  # noqa: E501

        库的名称 library name  # noqa: E501

        :return: The name of this LibraryInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LibraryInfo.

        库的名称 library name  # noqa: E501

        :param name: The name of this LibraryInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this LibraryInfo.  # noqa: E501


        :return: The type of this LibraryInfo.  # noqa: E501
        :rtype: LibraryTypeEnum
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LibraryInfo.


        :param type: The type of this LibraryInfo.  # noqa: E501
        :type: LibraryTypeEnum
        """

        self._type = type

    @property
    def business_type(self):
        """Gets the business_type of this LibraryInfo.  # noqa: E501


        :return: The business_type of this LibraryInfo.  # noqa: E501
        :rtype: BusinessTypeEnum
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this LibraryInfo.


        :param business_type: The business_type of this LibraryInfo.  # noqa: E501
        :type: BusinessTypeEnum
        """

        self._business_type = business_type

    @property
    def readonly(self):
        """Gets the readonly of this LibraryInfo.  # noqa: E501

        0代表可读写，1代表只读 0 for not readonly, 1 for readonly  # noqa: E501

        :return: The readonly of this LibraryInfo.  # noqa: E501
        :rtype: int
        """
        return self._readonly

    @readonly.setter
    def readonly(self, readonly):
        """Sets the readonly of this LibraryInfo.

        0代表可读写，1代表只读 0 for not readonly, 1 for readonly  # noqa: E501

        :param readonly: The readonly of this LibraryInfo.  # noqa: E501
        :type: int
        """

        self._readonly = readonly

    @property
    def bind_template(self):
        """Gets the bind_template of this LibraryInfo.  # noqa: E501

        1表示库直接绑定一个模板方案，0表示不绑定 1 for bind a template directly, 0 for not  # noqa: E501

        :return: The bind_template of this LibraryInfo.  # noqa: E501
        :rtype: int
        """
        return self._bind_template

    @bind_template.setter
    def bind_template(self, bind_template):
        """Sets the bind_template of this LibraryInfo.

        1表示库直接绑定一个模板方案，0表示不绑定 1 for bind a template directly, 0 for not  # noqa: E501

        :param bind_template: The bind_template of this LibraryInfo.  # noqa: E501
        :type: int
        """

        self._bind_template = bind_template

    @property
    def bind_library(self):
        """Gets the bind_library of this LibraryInfo.  # noqa: E501


        :return: The bind_library of this LibraryInfo.  # noqa: E501
        :rtype: LibraryTypeEnum
        """
        return self._bind_library

    @bind_library.setter
    def bind_library(self, bind_library):
        """Sets the bind_library of this LibraryInfo.


        :param bind_library: The bind_library of this LibraryInfo.  # noqa: E501
        :type: LibraryTypeEnum
        """

        self._bind_library = bind_library

    @property
    def bind_business(self):
        """Gets the bind_business of this LibraryInfo.  # noqa: E501


        :return: The bind_business of this LibraryInfo.  # noqa: E501
        :rtype: BusinessTypeEnum
        """
        return self._bind_business

    @bind_business.setter
    def bind_business(self, bind_business):
        """Sets the bind_business of this LibraryInfo.


        :param bind_business: The bind_business of this LibraryInfo.  # noqa: E501
        :type: BusinessTypeEnum
        """

        self._bind_business = bind_business

    @property
    def description(self):
        """Gets the description of this LibraryInfo.  # noqa: E501

        库的描述 description  # noqa: E501

        :return: The description of this LibraryInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LibraryInfo.

        库的描述 description  # noqa: E501

        :param description: The description of this LibraryInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enable_multi_template(self):
        """Gets the enable_multi_template of this LibraryInfo.  # noqa: E501

        0表示只能绑定单个模板方案，1表示可以绑定多个模板方案 0 for single template which is the default option, 1 for multiple templates  # noqa: E501

        :return: The enable_multi_template of this LibraryInfo.  # noqa: E501
        :rtype: int
        """
        return self._enable_multi_template

    @enable_multi_template.setter
    def enable_multi_template(self, enable_multi_template):
        """Sets the enable_multi_template of this LibraryInfo.

        0表示只能绑定单个模板方案，1表示可以绑定多个模板方案 0 for single template which is the default option, 1 for multiple templates  # noqa: E501

        :param enable_multi_template: The enable_multi_template of this LibraryInfo.  # noqa: E501
        :type: int
        """

        self._enable_multi_template = enable_multi_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LibraryInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LibraryInfo):
            return True

        return self.to_dict() != other.to_dict()
